@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2023  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2024  Salvo "LtWorf" Tomaselli
 #
 # Relation is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ def check_latest_version() -> Optional[str]:
     import urllib.request
 
     try:
-        req = urllib.request.Request('https://api.github.com/repos/ltworf/relational/releases')
+        req = urllib.request.Request('https://codeberg.org/api/v1/repos/ltworf/relational/releases/')
         with urllib.request.urlopen(req) as f:
             data = json.load(f)
         return data[0]['name']
