@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2023  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2024  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,13 +20,13 @@ from setuptools import setup
 
 def c_setup(name):
     setup(
-        version='3.1',
+        version='3.2',
         name=name,
         packages=(name,),
         author="Salvo 'LtWorf' Tomaselli",
         author_email='tiposchi@tiscali.it',
         maintainer="Salvo 'LtWorf' Tomaselli",
         maintainer_email='tiposchi@tiscali.it',
-        url='https://ltworf.github.io/relational/',
+        url='https://ltworf.codeberg.page/relational/',
         license='GPL3',
     )
